#
# spec file for package love
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without mpg123
Name:           love
Version:        11.3
Release:        bp154.1.53
Summary:        2D gaming engine written in Lua
License:        Zlib
Group:          Development/Languages/Other
URL:            http://love2d.org/
Source:         https://github.com/love2d/love/releases/download/%{version}/love-%{version}-linux-src.tar.gz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  libtool
BuildRequires:  physfs-devel
BuildRequires:  pkgconfig
BuildRequires:  shared-mime-info
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(IL)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(libenet)
BuildRequires:  pkgconfig(libmodplug)
BuildRequires:  pkgconfig(luajit)
BuildRequires:  pkgconfig(openal)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(theora)
BuildRequires:  pkgconfig(vorbisfile)
Requires(pre):  desktop-file-utils
Requires(pre):  shared-mime-info
%if %{with mpg123}
BuildRequires:  pkgconfig(libmpg123)
%endif

%description
LÖVE is a framework for making 2D games in Lua.

%prep
%setup -q
sed -i 's/\r$//' *.txt

%build
autoreconf -fi
%configure \
%if %{without mpg123}
	--disable-mpg123 \
%endif
	--disable-static
make %{?_smp_mflags}

%install
%make_install
rm "%{buildroot}%{_libdir}/liblove.la" "%{buildroot}%{_libdir}/liblove.so"

%post
/sbin/ldconfig
%desktop_database_post
%icon_theme_cache_post
%mime_database_post

%postun
/sbin/ldconfig
%desktop_database_postun
%icon_theme_cache_postun
%mime_database_postun

%files
%license license.txt
%doc changes.txt readme.md
%{_bindir}/love
%{_libdir}/liblove-%{version}.so
%{_datadir}/applications/love.desktop
%{_mandir}/man1/love.1%{?ext_man}
%{_datadir}/icons/hicolor/scalable/mimetypes/application-x-love-game.svg
%{_datadir}/mime/packages/love.xml
%{_datadir}/pixmaps/love.svg

%changelog
* Wed Jul 28 2021 Dirk Stoecker <opensuse@dstoecker.de>
- Drop remove-duplicate-typedef.patch as it causes build failure for i586 now
* Mon Aug 24 2020 Dirk Mueller <dmueller@suse.com>
- update to 11.3:
  * Added support for FLAC audio files.
  * Added support for microphone recording on Android.
  * Added t.audio.mic (false by default). On Android, setting it to true requests microphone recording permission from the user.
  * Added Decoder:clone.
  * Added Data:getFFIPointer.
  * Added Joystick:getDeviceInfo.
  * Added Joystick:getGamepadMappingString and love.joystick.getGamepadMappingString(guid).
  * Added love.math.colorToBytes and love.math.colorFromBytes.
  * Added 'usedpiscale' boolean (true by default) to love.window.setMode and love.conf. Disables automatic DPI scaling when false.
  * Added love.window.getDisplayOrientation and a love.displayrotated callback.
  * Added love.window.get/setVSync, to allow setting vsync without recreating the window.
  * Added love.window.getSafeArea.
  * Added an optional vertex count parameter to Mesh:setVertices.
  * Added support for rgba4, rgb5a1, rgb565, rgb10a2, rg11b10f, r8, rg8, r16, rg16, r16f, rg16f, r32f, and rg32f formats in ImageData and Images.
  * Added support for loading .dds files that contain uncompressed pixel data.
  * Changed audio file type detection, so it probes all supported backends for unrecognized extensions.
  * Fixed "bad lightuserdata" errors when running love on some arm64 devices.
  * Fixed boot.lua's line numbers in stack traces to match its source code.
  * Fixed the deprecation system not fully restarting when love.event.quit("restart") is used.
  * Fixed love.isVersionCompatible.
  * Fixed named Channels persisting across love.event.quit("restart") occurrences.
  * Fixed race conditions when different love.physics Worlds are used in different threads.
  * Fixed World:getJoints to return the fully resolved type of the Joint, instead of the base type.
  * Fixed love.timer.sleep(0) to return control to the OS scheduler instead of being a no-op.
  * Fixed love.math.randomNormal incorrectly using cached state after love.math.setRandomSeed or setRandomState.
  * Fixed love.data.hash returning an incorrect hash for certain input sizes.
  * Fixed love.data.newByteData to cause a Lua error instead of crashing when invalid arguments are used.
  * Fixed the Data-returning variant of love.filesystem.read and File:read to return the number of bytes that were read.
  * Fixed love.filesystem's require loaders to error instead of crashing when no argument is given.
  * Fixed love.filesystem.mount(Data).
  * Fixed a memory leak when loading files in some situations.
  * Fixed t.audio.mixwithsystem.
  * Fixed audio clicks immediately after playing a Source on iOS.
  * Fixed Source:play + Source:stop + Source:play looping the first few ms of sound for streaming Sources on iOS.
  * Fixed Source:play + Source:seek looping the first few ms of sound for streaming Sources on iOS.
  * Fixed occasional pops in streaming sources on iOS.
  * Fixed love.audio.play(sources) to use previously set playback positions on stopped Sources.
  * Fixed Source:setEffect(name, true) and Source:getEffect(name) when the effect has no associated Filter.
  * Fixed love.audio.newSource(filename, "queue") to cause a Lua error.
  * Fixed Source:setPitch to error if the given pitch is <= 0, NaN, or infinity.
  * Fixed video seeking and pausing in various scenarios.
  * Fixed an audio Source memory leak when a Video gets garbage collected after playing it.
  * Fixed video playback support on some Adreno-based Android devices.
  * Fixed black fringes around text in some situations.
  * Fixed extreme flickering when text moves along non-integer coordinates.
  * Fixed the first character in a string sometimes not being processed during text vertex generation.
  * Fixed Text:set(" ") not clearing any previously set text in a Text object.
  * Fixed love.graphics.getTextureTypes to return a table with boolean values in its fields instead of number values.
  * Fixed lines not rendering properly if a single line has more than 65,000 vertices.
  * Fixed a pixel shader performance regression on some graphics drivers when OpenGL 3 or OpenGL ES 3 is used.
  * Fixed text not showing up on Radeon HD 3000-series graphics cards on Windows.
  * Fixed non-integer DPI scale values being truncated to integers in love.graphics.newCanvas.
  * Fixed creating depth canvases on Windows systems when using an Intel HD 3000 GPU.
  * Fixed automatic batching performance to be more consistent on all operating systems.
  * Fixed gammaToLinearPrecise in shaders not being as precise as it should be.
  * Fixed ImageData:paste and ImageData:setPixel to have more consistent clamping and rounding of color values when different formats are used.
- remove love-11.2-return.patch: upstream
* Thu Apr 23 2020 Max Mitschke <maxmitschke@fastmail.com>
- Added remove-duplicate-typedef.patch to fix i586 build
* Wed Nov 28 2018 mvetter@suse.com
- Update to 11.2:
  Additions:
  * Added Source:setAirAbsorption and Source:getAirAbsorption.
  * Added Body:setTransform and Body:getTransform.
  Performance Improvements:
  * Improved performance of love.graphics.draw slightly on iOS and Android.
  Fixes:
  * Fixed love.filesystem initialization on Windows 10 update 1809.
  * Fixed various issues with running on macOS 10.14.
  * Fixed compatibility with Lua 5.2 and 5.3.
  * Fixed the explicit format + Data argument variant of love.data.decompress.
  * Fixed love.joystick.setGamepadMapping not being able to change existing mappings.
  * Fixed a crash on quit on Linux if a custom Cursor is active when quitting.
  * Fixed a crash in the Data variant of Shader:send when it's called after love.window.setMode.
  * Fixed a love.graphics.setCanvas error message to be less confusing.
- Add love-11.2-return.patch: to make compiler happy
- Remove love.mpg123.patch: don't see why needed anymore
- Remove update-luasocket.patch: upstreamed
- Run spec-cleaner
* Sat Jun 24 2017 rpm@fthiessen.de
- Added update-luasocket.patch from upstream  to fix build with lua53
* Mon Apr 17 2017 olaf@aepfle.de
- Build with mpg123 unconditionally, add love.mpg123.patch
- Run autoreconf
- Add Requires(pre) as needed
* Sat Jan 21 2017 prusnak@opensuse.org
- Update to version 0.10.2
* Thu Jul 28 2016 rpm@fthiessen.de
- Dropped unneeded devel package
- Removed now unneeded love-modplug.patch
* Thu Jul 28 2016 rpm@fthiessen.de
- Update to version 0.10.1
* Thu Mar  5 2015 stefan@fam-elser.de
- update to version 0.9.2
* Sun Sep 14 2014 mailaender@opensuse.org
- update to version 0.9.1
- added -devel package to solve the rpmlint error
- added post script macros for desktop, icon and mime
* Sun Dec 15 2013 prusnak@opensuse.org
- updated to 0.9.0
  * Added three new modules: love.window, love.math, and love.system.
  * Reworked the love.joystick and love.thread modules.
  * Added new features to love.graphics, including polygon meshes and vertex shaders.
  * Integrated the ENet networking library via lua-enet.
  * Renamed many functions to be more consistent with the rest of the API.
  * Improved the performance of several APIs in love.graphics.
  * And a lot more!
- dropped remove-mpg123.patch (applied upstream)
* Sun Feb 17 2013 jengelh@inai.de
- Sanitize description to not read like an ad. Use project's
  actual name with diacritic marks.
- Use more robust make install call.
* Sun Apr 15 2012 prusnak@opensuse.org
- updated to 0.8.0 release
- removed unneeded_deps.patch (applied upstream)
* Thu Mar 22 2012 reddwarf@opensuse.org
- make MP3 support optional
- change licence to follow SPDX
- remove unneded libmng-devel and libtiff-devel build dependencies
- use pkgconfig() style build dependencies
- remove love-modplug.patch for >= 12.1
- force lua 5.1 and add autotools BT to fix Factory build
* Sun Mar 11 2012 prusnak@opensuse.org
- update to mercurial tip (upcoming 0.8.0)
* Tue Sep 13 2011 jmatejek@suse.com
- build fix - added devel dependencies for DevIL
- standard group name
* Wed Jun 22 2011 prusnak@opensuse.org
- created package (version 0.7.2)
